/*******************************************************************************
* File Name: Divider.h
* Version 2.10
*
* Description:
*  This file provides constants and parameter values for the Divider
*  component.
*
* Note:
*  None
*
********************************************************************************
* Copyright 2013-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_TCPWM_Divider_H)
#define CY_TCPWM_Divider_H


#include "CyLib.h"
#include "cytypes.h"
#include "cyfitter.h"


/*******************************************************************************
* Internal Type defines
*******************************************************************************/

/* Structure to save state before go to sleep */
typedef struct
{
    uint8  enableState;
} Divider_BACKUP_STRUCT;


/*******************************************************************************
* Variables
*******************************************************************************/
extern uint8  Divider_initVar;


/***************************************
*   Conditional Compilation Parameters
****************************************/

#define Divider_CY_TCPWM_V2                    (CYIPBLOCK_m0s8tcpwm_VERSION == 2u)
#define Divider_CY_TCPWM_4000                  (CY_PSOC4_4000)

/* TCPWM Configuration */
#define Divider_CONFIG                         (7lu)

/* Quad Mode */
/* Parameters */
#define Divider_QUAD_ENCODING_MODES            (0lu)
#define Divider_QUAD_AUTO_START                (1lu)

/* Signal modes */
#define Divider_QUAD_INDEX_SIGNAL_MODE         (0lu)
#define Divider_QUAD_PHIA_SIGNAL_MODE          (3lu)
#define Divider_QUAD_PHIB_SIGNAL_MODE          (3lu)
#define Divider_QUAD_STOP_SIGNAL_MODE          (0lu)

/* Signal present */
#define Divider_QUAD_INDEX_SIGNAL_PRESENT      (0lu)
#define Divider_QUAD_STOP_SIGNAL_PRESENT       (0lu)

/* Interrupt Mask */
#define Divider_QUAD_INTERRUPT_MASK            (1lu)

/* Timer/Counter Mode */
/* Parameters */
#define Divider_TC_RUN_MODE                    (0lu)
#define Divider_TC_COUNTER_MODE                (1lu)
#define Divider_TC_COMP_CAP_MODE               (0lu)
#define Divider_TC_PRESCALER                   (0lu)

/* Signal modes */
#define Divider_TC_RELOAD_SIGNAL_MODE          (0lu)
#define Divider_TC_COUNT_SIGNAL_MODE           (0lu)
#define Divider_TC_START_SIGNAL_MODE           (0lu)
#define Divider_TC_STOP_SIGNAL_MODE            (0lu)
#define Divider_TC_CAPTURE_SIGNAL_MODE         (0lu)

/* Signal present */
#define Divider_TC_RELOAD_SIGNAL_PRESENT       (0lu)
#define Divider_TC_COUNT_SIGNAL_PRESENT        (1lu)
#define Divider_TC_START_SIGNAL_PRESENT        (0lu)
#define Divider_TC_STOP_SIGNAL_PRESENT         (0lu)
#define Divider_TC_CAPTURE_SIGNAL_PRESENT      (0lu)

/* Interrupt Mask */
#define Divider_TC_INTERRUPT_MASK              (1lu)

/* PWM Mode */
/* Parameters */
#define Divider_PWM_KILL_EVENT                 (0lu)
#define Divider_PWM_STOP_EVENT                 (0lu)
#define Divider_PWM_MODE                       (4lu)
#define Divider_PWM_OUT_N_INVERT               (0lu)
#define Divider_PWM_OUT_INVERT                 (0lu)
#define Divider_PWM_ALIGN                      (0lu)
#define Divider_PWM_RUN_MODE                   (0lu)
#define Divider_PWM_DEAD_TIME_CYCLE            (0lu)
#define Divider_PWM_PRESCALER                  (0lu)

/* Signal modes */
#define Divider_PWM_RELOAD_SIGNAL_MODE         (0lu)
#define Divider_PWM_COUNT_SIGNAL_MODE          (0lu)
#define Divider_PWM_START_SIGNAL_MODE          (0lu)
#define Divider_PWM_STOP_SIGNAL_MODE           (0lu)
#define Divider_PWM_SWITCH_SIGNAL_MODE         (0lu)

/* Signal present */
#define Divider_PWM_RELOAD_SIGNAL_PRESENT      (0lu)
#define Divider_PWM_COUNT_SIGNAL_PRESENT       (1lu)
#define Divider_PWM_START_SIGNAL_PRESENT       (0lu)
#define Divider_PWM_STOP_SIGNAL_PRESENT        (0lu)
#define Divider_PWM_SWITCH_SIGNAL_PRESENT      (0lu)

/* Interrupt Mask */
#define Divider_PWM_INTERRUPT_MASK             (1lu)


/***************************************
*    Initial Parameter Constants
***************************************/

/* Timer/Counter Mode */
#define Divider_TC_PERIOD_VALUE                (99lu)
#define Divider_TC_COMPARE_VALUE               (0lu)
#define Divider_TC_COMPARE_BUF_VALUE           (65535lu)
#define Divider_TC_COMPARE_SWAP                (0lu)

/* PWM Mode */
#define Divider_PWM_PERIOD_VALUE               (9lu)
#define Divider_PWM_PERIOD_BUF_VALUE           (65535lu)
#define Divider_PWM_PERIOD_SWAP                (0lu)
#define Divider_PWM_COMPARE_VALUE              (5lu)
#define Divider_PWM_COMPARE_BUF_VALUE          (65535lu)
#define Divider_PWM_COMPARE_SWAP               (0lu)


/***************************************
*    Enumerated Types and Parameters
***************************************/

#define Divider__LEFT 0
#define Divider__RIGHT 1
#define Divider__CENTER 2
#define Divider__ASYMMETRIC 3

#define Divider__X1 0
#define Divider__X2 1
#define Divider__X4 2

#define Divider__PWM 4
#define Divider__PWM_DT 5
#define Divider__PWM_PR 6

#define Divider__INVERSE 1
#define Divider__DIRECT 0

#define Divider__CAPTURE 2
#define Divider__COMPARE 0

#define Divider__TRIG_LEVEL 3
#define Divider__TRIG_RISING 0
#define Divider__TRIG_FALLING 1
#define Divider__TRIG_BOTH 2

#define Divider__INTR_MASK_TC 1
#define Divider__INTR_MASK_CC_MATCH 2
#define Divider__INTR_MASK_NONE 0
#define Divider__INTR_MASK_TC_CC 3

#define Divider__UNCONFIG 8
#define Divider__TIMER 1
#define Divider__QUAD 3
#define Divider__PWM_SEL 7

#define Divider__COUNT_UP 0
#define Divider__COUNT_DOWN 1
#define Divider__COUNT_UPDOWN0 2
#define Divider__COUNT_UPDOWN1 3


/* Prescaler */
#define Divider_PRESCALE_DIVBY1                ((uint32)(0u << Divider_PRESCALER_SHIFT))
#define Divider_PRESCALE_DIVBY2                ((uint32)(1u << Divider_PRESCALER_SHIFT))
#define Divider_PRESCALE_DIVBY4                ((uint32)(2u << Divider_PRESCALER_SHIFT))
#define Divider_PRESCALE_DIVBY8                ((uint32)(3u << Divider_PRESCALER_SHIFT))
#define Divider_PRESCALE_DIVBY16               ((uint32)(4u << Divider_PRESCALER_SHIFT))
#define Divider_PRESCALE_DIVBY32               ((uint32)(5u << Divider_PRESCALER_SHIFT))
#define Divider_PRESCALE_DIVBY64               ((uint32)(6u << Divider_PRESCALER_SHIFT))
#define Divider_PRESCALE_DIVBY128              ((uint32)(7u << Divider_PRESCALER_SHIFT))

/* TCPWM set modes */
#define Divider_MODE_TIMER_COMPARE             ((uint32)(Divider__COMPARE         <<  \
                                                                  Divider_MODE_SHIFT))
#define Divider_MODE_TIMER_CAPTURE             ((uint32)(Divider__CAPTURE         <<  \
                                                                  Divider_MODE_SHIFT))
#define Divider_MODE_QUAD                      ((uint32)(Divider__QUAD            <<  \
                                                                  Divider_MODE_SHIFT))
#define Divider_MODE_PWM                       ((uint32)(Divider__PWM             <<  \
                                                                  Divider_MODE_SHIFT))
#define Divider_MODE_PWM_DT                    ((uint32)(Divider__PWM_DT          <<  \
                                                                  Divider_MODE_SHIFT))
#define Divider_MODE_PWM_PR                    ((uint32)(Divider__PWM_PR          <<  \
                                                                  Divider_MODE_SHIFT))

/* Quad Modes */
#define Divider_MODE_X1                        ((uint32)(Divider__X1              <<  \
                                                                  Divider_QUAD_MODE_SHIFT))
#define Divider_MODE_X2                        ((uint32)(Divider__X2              <<  \
                                                                  Divider_QUAD_MODE_SHIFT))
#define Divider_MODE_X4                        ((uint32)(Divider__X4              <<  \
                                                                  Divider_QUAD_MODE_SHIFT))

/* Counter modes */
#define Divider_COUNT_UP                       ((uint32)(Divider__COUNT_UP        <<  \
                                                                  Divider_UPDOWN_SHIFT))
#define Divider_COUNT_DOWN                     ((uint32)(Divider__COUNT_DOWN      <<  \
                                                                  Divider_UPDOWN_SHIFT))
#define Divider_COUNT_UPDOWN0                  ((uint32)(Divider__COUNT_UPDOWN0   <<  \
                                                                  Divider_UPDOWN_SHIFT))
#define Divider_COUNT_UPDOWN1                  ((uint32)(Divider__COUNT_UPDOWN1   <<  \
                                                                  Divider_UPDOWN_SHIFT))

/* PWM output invert */
#define Divider_INVERT_LINE                    ((uint32)(Divider__INVERSE         <<  \
                                                                  Divider_INV_OUT_SHIFT))
#define Divider_INVERT_LINE_N                  ((uint32)(Divider__INVERSE         <<  \
                                                                  Divider_INV_COMPL_OUT_SHIFT))

/* Trigger modes */
#define Divider_TRIG_RISING                    ((uint32)Divider__TRIG_RISING)
#define Divider_TRIG_FALLING                   ((uint32)Divider__TRIG_FALLING)
#define Divider_TRIG_BOTH                      ((uint32)Divider__TRIG_BOTH)
#define Divider_TRIG_LEVEL                     ((uint32)Divider__TRIG_LEVEL)

/* Interrupt mask */
#define Divider_INTR_MASK_TC                   ((uint32)Divider__INTR_MASK_TC)
#define Divider_INTR_MASK_CC_MATCH             ((uint32)Divider__INTR_MASK_CC_MATCH)

/* PWM Output Controls */
#define Divider_CC_MATCH_SET                   (0x00u)
#define Divider_CC_MATCH_CLEAR                 (0x01u)
#define Divider_CC_MATCH_INVERT                (0x02u)
#define Divider_CC_MATCH_NO_CHANGE             (0x03u)
#define Divider_OVERLOW_SET                    (0x00u)
#define Divider_OVERLOW_CLEAR                  (0x04u)
#define Divider_OVERLOW_INVERT                 (0x08u)
#define Divider_OVERLOW_NO_CHANGE              (0x0Cu)
#define Divider_UNDERFLOW_SET                  (0x00u)
#define Divider_UNDERFLOW_CLEAR                (0x10u)
#define Divider_UNDERFLOW_INVERT               (0x20u)
#define Divider_UNDERFLOW_NO_CHANGE            (0x30u)

/* PWM Align */
#define Divider_PWM_MODE_LEFT                  (Divider_CC_MATCH_CLEAR        |   \
                                                         Divider_OVERLOW_SET           |   \
                                                         Divider_UNDERFLOW_NO_CHANGE)
#define Divider_PWM_MODE_RIGHT                 (Divider_CC_MATCH_SET          |   \
                                                         Divider_OVERLOW_NO_CHANGE     |   \
                                                         Divider_UNDERFLOW_CLEAR)
#define Divider_PWM_MODE_ASYM                  (Divider_CC_MATCH_INVERT       |   \
                                                         Divider_OVERLOW_SET           |   \
                                                         Divider_UNDERFLOW_CLEAR)

#if (Divider_CY_TCPWM_V2)
    #if(Divider_CY_TCPWM_4000)
        #define Divider_PWM_MODE_CENTER                (Divider_CC_MATCH_INVERT       |   \
                                                                 Divider_OVERLOW_NO_CHANGE     |   \
                                                                 Divider_UNDERFLOW_CLEAR)
    #else
        #define Divider_PWM_MODE_CENTER                (Divider_CC_MATCH_INVERT       |   \
                                                                 Divider_OVERLOW_SET           |   \
                                                                 Divider_UNDERFLOW_CLEAR)
    #endif /* (Divider_CY_TCPWM_4000) */
#else
    #define Divider_PWM_MODE_CENTER                (Divider_CC_MATCH_INVERT       |   \
                                                             Divider_OVERLOW_NO_CHANGE     |   \
                                                             Divider_UNDERFLOW_CLEAR)
#endif /* (Divider_CY_TCPWM_NEW) */

/* Command operations without condition */
#define Divider_CMD_CAPTURE                    (0u)
#define Divider_CMD_RELOAD                     (8u)
#define Divider_CMD_STOP                       (16u)
#define Divider_CMD_START                      (24u)

/* Status */
#define Divider_STATUS_DOWN                    (1u)
#define Divider_STATUS_RUNNING                 (2u)


/***************************************
*        Function Prototypes
****************************************/

void   Divider_Init(void);
void   Divider_Enable(void);
void   Divider_Start(void);
void   Divider_Stop(void);

void   Divider_SetMode(uint32 mode);
void   Divider_SetCounterMode(uint32 counterMode);
void   Divider_SetPWMMode(uint32 modeMask);
void   Divider_SetQDMode(uint32 qdMode);

void   Divider_SetPrescaler(uint32 prescaler);
void   Divider_TriggerCommand(uint32 mask, uint32 command);
void   Divider_SetOneShot(uint32 oneShotEnable);
uint32 Divider_ReadStatus(void);

void   Divider_SetPWMSyncKill(uint32 syncKillEnable);
void   Divider_SetPWMStopOnKill(uint32 stopOnKillEnable);
void   Divider_SetPWMDeadTime(uint32 deadTime);
void   Divider_SetPWMInvert(uint32 mask);

void   Divider_SetInterruptMode(uint32 interruptMask);
uint32 Divider_GetInterruptSourceMasked(void);
uint32 Divider_GetInterruptSource(void);
void   Divider_ClearInterrupt(uint32 interruptMask);
void   Divider_SetInterrupt(uint32 interruptMask);

void   Divider_WriteCounter(uint32 count);
uint32 Divider_ReadCounter(void);

uint32 Divider_ReadCapture(void);
uint32 Divider_ReadCaptureBuf(void);

void   Divider_WritePeriod(uint32 period);
uint32 Divider_ReadPeriod(void);
void   Divider_WritePeriodBuf(uint32 periodBuf);
uint32 Divider_ReadPeriodBuf(void);

void   Divider_WriteCompare(uint32 compare);
uint32 Divider_ReadCompare(void);
void   Divider_WriteCompareBuf(uint32 compareBuf);
uint32 Divider_ReadCompareBuf(void);

void   Divider_SetPeriodSwap(uint32 swapEnable);
void   Divider_SetCompareSwap(uint32 swapEnable);

void   Divider_SetCaptureMode(uint32 triggerMode);
void   Divider_SetReloadMode(uint32 triggerMode);
void   Divider_SetStartMode(uint32 triggerMode);
void   Divider_SetStopMode(uint32 triggerMode);
void   Divider_SetCountMode(uint32 triggerMode);

void   Divider_SaveConfig(void);
void   Divider_RestoreConfig(void);
void   Divider_Sleep(void);
void   Divider_Wakeup(void);


/***************************************
*             Registers
***************************************/

#define Divider_BLOCK_CONTROL_REG              (*(reg32 *) Divider_cy_m0s8_tcpwm_1__TCPWM_CTRL )
#define Divider_BLOCK_CONTROL_PTR              ( (reg32 *) Divider_cy_m0s8_tcpwm_1__TCPWM_CTRL )
#define Divider_COMMAND_REG                    (*(reg32 *) Divider_cy_m0s8_tcpwm_1__TCPWM_CMD )
#define Divider_COMMAND_PTR                    ( (reg32 *) Divider_cy_m0s8_tcpwm_1__TCPWM_CMD )
#define Divider_INTRRUPT_CAUSE_REG             (*(reg32 *) Divider_cy_m0s8_tcpwm_1__TCPWM_INTR_CAUSE )
#define Divider_INTRRUPT_CAUSE_PTR             ( (reg32 *) Divider_cy_m0s8_tcpwm_1__TCPWM_INTR_CAUSE )
#define Divider_CONTROL_REG                    (*(reg32 *) Divider_cy_m0s8_tcpwm_1__CTRL )
#define Divider_CONTROL_PTR                    ( (reg32 *) Divider_cy_m0s8_tcpwm_1__CTRL )
#define Divider_STATUS_REG                     (*(reg32 *) Divider_cy_m0s8_tcpwm_1__STATUS )
#define Divider_STATUS_PTR                     ( (reg32 *) Divider_cy_m0s8_tcpwm_1__STATUS )
#define Divider_COUNTER_REG                    (*(reg32 *) Divider_cy_m0s8_tcpwm_1__COUNTER )
#define Divider_COUNTER_PTR                    ( (reg32 *) Divider_cy_m0s8_tcpwm_1__COUNTER )
#define Divider_COMP_CAP_REG                   (*(reg32 *) Divider_cy_m0s8_tcpwm_1__CC )
#define Divider_COMP_CAP_PTR                   ( (reg32 *) Divider_cy_m0s8_tcpwm_1__CC )
#define Divider_COMP_CAP_BUF_REG               (*(reg32 *) Divider_cy_m0s8_tcpwm_1__CC_BUFF )
#define Divider_COMP_CAP_BUF_PTR               ( (reg32 *) Divider_cy_m0s8_tcpwm_1__CC_BUFF )
#define Divider_PERIOD_REG                     (*(reg32 *) Divider_cy_m0s8_tcpwm_1__PERIOD )
#define Divider_PERIOD_PTR                     ( (reg32 *) Divider_cy_m0s8_tcpwm_1__PERIOD )
#define Divider_PERIOD_BUF_REG                 (*(reg32 *) Divider_cy_m0s8_tcpwm_1__PERIOD_BUFF )
#define Divider_PERIOD_BUF_PTR                 ( (reg32 *) Divider_cy_m0s8_tcpwm_1__PERIOD_BUFF )
#define Divider_TRIG_CONTROL0_REG              (*(reg32 *) Divider_cy_m0s8_tcpwm_1__TR_CTRL0 )
#define Divider_TRIG_CONTROL0_PTR              ( (reg32 *) Divider_cy_m0s8_tcpwm_1__TR_CTRL0 )
#define Divider_TRIG_CONTROL1_REG              (*(reg32 *) Divider_cy_m0s8_tcpwm_1__TR_CTRL1 )
#define Divider_TRIG_CONTROL1_PTR              ( (reg32 *) Divider_cy_m0s8_tcpwm_1__TR_CTRL1 )
#define Divider_TRIG_CONTROL2_REG              (*(reg32 *) Divider_cy_m0s8_tcpwm_1__TR_CTRL2 )
#define Divider_TRIG_CONTROL2_PTR              ( (reg32 *) Divider_cy_m0s8_tcpwm_1__TR_CTRL2 )
#define Divider_INTERRUPT_REQ_REG              (*(reg32 *) Divider_cy_m0s8_tcpwm_1__INTR )
#define Divider_INTERRUPT_REQ_PTR              ( (reg32 *) Divider_cy_m0s8_tcpwm_1__INTR )
#define Divider_INTERRUPT_SET_REG              (*(reg32 *) Divider_cy_m0s8_tcpwm_1__INTR_SET )
#define Divider_INTERRUPT_SET_PTR              ( (reg32 *) Divider_cy_m0s8_tcpwm_1__INTR_SET )
#define Divider_INTERRUPT_MASK_REG             (*(reg32 *) Divider_cy_m0s8_tcpwm_1__INTR_MASK )
#define Divider_INTERRUPT_MASK_PTR             ( (reg32 *) Divider_cy_m0s8_tcpwm_1__INTR_MASK )
#define Divider_INTERRUPT_MASKED_REG           (*(reg32 *) Divider_cy_m0s8_tcpwm_1__INTR_MASKED )
#define Divider_INTERRUPT_MASKED_PTR           ( (reg32 *) Divider_cy_m0s8_tcpwm_1__INTR_MASKED )


/***************************************
*       Registers Constants
***************************************/

/* Mask */
#define Divider_MASK                           ((uint32)Divider_cy_m0s8_tcpwm_1__TCPWM_CTRL_MASK)

/* Shift constants for control register */
#define Divider_RELOAD_CC_SHIFT                (0u)
#define Divider_RELOAD_PERIOD_SHIFT            (1u)
#define Divider_PWM_SYNC_KILL_SHIFT            (2u)
#define Divider_PWM_STOP_KILL_SHIFT            (3u)
#define Divider_PRESCALER_SHIFT                (8u)
#define Divider_UPDOWN_SHIFT                   (16u)
#define Divider_ONESHOT_SHIFT                  (18u)
#define Divider_QUAD_MODE_SHIFT                (20u)
#define Divider_INV_OUT_SHIFT                  (20u)
#define Divider_INV_COMPL_OUT_SHIFT            (21u)
#define Divider_MODE_SHIFT                     (24u)

/* Mask constants for control register */
#define Divider_RELOAD_CC_MASK                 ((uint32)(Divider_1BIT_MASK        <<  \
                                                                            Divider_RELOAD_CC_SHIFT))
#define Divider_RELOAD_PERIOD_MASK             ((uint32)(Divider_1BIT_MASK        <<  \
                                                                            Divider_RELOAD_PERIOD_SHIFT))
#define Divider_PWM_SYNC_KILL_MASK             ((uint32)(Divider_1BIT_MASK        <<  \
                                                                            Divider_PWM_SYNC_KILL_SHIFT))
#define Divider_PWM_STOP_KILL_MASK             ((uint32)(Divider_1BIT_MASK        <<  \
                                                                            Divider_PWM_STOP_KILL_SHIFT))
#define Divider_PRESCALER_MASK                 ((uint32)(Divider_8BIT_MASK        <<  \
                                                                            Divider_PRESCALER_SHIFT))
#define Divider_UPDOWN_MASK                    ((uint32)(Divider_2BIT_MASK        <<  \
                                                                            Divider_UPDOWN_SHIFT))
#define Divider_ONESHOT_MASK                   ((uint32)(Divider_1BIT_MASK        <<  \
                                                                            Divider_ONESHOT_SHIFT))
#define Divider_QUAD_MODE_MASK                 ((uint32)(Divider_3BIT_MASK        <<  \
                                                                            Divider_QUAD_MODE_SHIFT))
#define Divider_INV_OUT_MASK                   ((uint32)(Divider_2BIT_MASK        <<  \
                                                                            Divider_INV_OUT_SHIFT))
#define Divider_MODE_MASK                      ((uint32)(Divider_3BIT_MASK        <<  \
                                                                            Divider_MODE_SHIFT))

/* Shift constants for trigger control register 1 */
#define Divider_CAPTURE_SHIFT                  (0u)
#define Divider_COUNT_SHIFT                    (2u)
#define Divider_RELOAD_SHIFT                   (4u)
#define Divider_STOP_SHIFT                     (6u)
#define Divider_START_SHIFT                    (8u)

/* Mask constants for trigger control register 1 */
#define Divider_CAPTURE_MASK                   ((uint32)(Divider_2BIT_MASK        <<  \
                                                                  Divider_CAPTURE_SHIFT))
#define Divider_COUNT_MASK                     ((uint32)(Divider_2BIT_MASK        <<  \
                                                                  Divider_COUNT_SHIFT))
#define Divider_RELOAD_MASK                    ((uint32)(Divider_2BIT_MASK        <<  \
                                                                  Divider_RELOAD_SHIFT))
#define Divider_STOP_MASK                      ((uint32)(Divider_2BIT_MASK        <<  \
                                                                  Divider_STOP_SHIFT))
#define Divider_START_MASK                     ((uint32)(Divider_2BIT_MASK        <<  \
                                                                  Divider_START_SHIFT))

/* MASK */
#define Divider_1BIT_MASK                      ((uint32)0x01u)
#define Divider_2BIT_MASK                      ((uint32)0x03u)
#define Divider_3BIT_MASK                      ((uint32)0x07u)
#define Divider_6BIT_MASK                      ((uint32)0x3Fu)
#define Divider_8BIT_MASK                      ((uint32)0xFFu)
#define Divider_16BIT_MASK                     ((uint32)0xFFFFu)

/* Shift constant for status register */
#define Divider_RUNNING_STATUS_SHIFT           (30u)


/***************************************
*    Initial Constants
***************************************/

#define Divider_CTRL_QUAD_BASE_CONFIG                                                          \
        (((uint32)(Divider_QUAD_ENCODING_MODES     << Divider_QUAD_MODE_SHIFT))       |\
         ((uint32)(Divider_CONFIG                  << Divider_MODE_SHIFT)))

#define Divider_CTRL_PWM_BASE_CONFIG                                                           \
        (((uint32)(Divider_PWM_STOP_EVENT          << Divider_PWM_STOP_KILL_SHIFT))   |\
         ((uint32)(Divider_PWM_OUT_INVERT          << Divider_INV_OUT_SHIFT))         |\
         ((uint32)(Divider_PWM_OUT_N_INVERT        << Divider_INV_COMPL_OUT_SHIFT))   |\
         ((uint32)(Divider_PWM_MODE                << Divider_MODE_SHIFT)))

#define Divider_CTRL_PWM_RUN_MODE                                                              \
            ((uint32)(Divider_PWM_RUN_MODE         << Divider_ONESHOT_SHIFT))
            
#define Divider_CTRL_PWM_ALIGN                                                                 \
            ((uint32)(Divider_PWM_ALIGN            << Divider_UPDOWN_SHIFT))

#define Divider_CTRL_PWM_KILL_EVENT                                                            \
             ((uint32)(Divider_PWM_KILL_EVENT      << Divider_PWM_SYNC_KILL_SHIFT))

#define Divider_CTRL_PWM_DEAD_TIME_CYCLE                                                       \
            ((uint32)(Divider_PWM_DEAD_TIME_CYCLE  << Divider_PRESCALER_SHIFT))

#define Divider_CTRL_PWM_PRESCALER                                                             \
            ((uint32)(Divider_PWM_PRESCALER        << Divider_PRESCALER_SHIFT))

#define Divider_CTRL_TIMER_BASE_CONFIG                                                         \
        (((uint32)(Divider_TC_PRESCALER            << Divider_PRESCALER_SHIFT))       |\
         ((uint32)(Divider_TC_COUNTER_MODE         << Divider_UPDOWN_SHIFT))          |\
         ((uint32)(Divider_TC_RUN_MODE             << Divider_ONESHOT_SHIFT))         |\
         ((uint32)(Divider_TC_COMP_CAP_MODE        << Divider_MODE_SHIFT)))
        
#define Divider_QUAD_SIGNALS_MODES                                                             \
        (((uint32)(Divider_QUAD_PHIA_SIGNAL_MODE   << Divider_COUNT_SHIFT))           |\
         ((uint32)(Divider_QUAD_INDEX_SIGNAL_MODE  << Divider_RELOAD_SHIFT))          |\
         ((uint32)(Divider_QUAD_STOP_SIGNAL_MODE   << Divider_STOP_SHIFT))            |\
         ((uint32)(Divider_QUAD_PHIB_SIGNAL_MODE   << Divider_START_SHIFT)))

#define Divider_PWM_SIGNALS_MODES                                                              \
        (((uint32)(Divider_PWM_SWITCH_SIGNAL_MODE  << Divider_CAPTURE_SHIFT))         |\
         ((uint32)(Divider_PWM_COUNT_SIGNAL_MODE   << Divider_COUNT_SHIFT))           |\
         ((uint32)(Divider_PWM_RELOAD_SIGNAL_MODE  << Divider_RELOAD_SHIFT))          |\
         ((uint32)(Divider_PWM_STOP_SIGNAL_MODE    << Divider_STOP_SHIFT))            |\
         ((uint32)(Divider_PWM_START_SIGNAL_MODE   << Divider_START_SHIFT)))

#define Divider_TIMER_SIGNALS_MODES                                                            \
        (((uint32)(Divider_TC_CAPTURE_SIGNAL_MODE  << Divider_CAPTURE_SHIFT))         |\
         ((uint32)(Divider_TC_COUNT_SIGNAL_MODE    << Divider_COUNT_SHIFT))           |\
         ((uint32)(Divider_TC_RELOAD_SIGNAL_MODE   << Divider_RELOAD_SHIFT))          |\
         ((uint32)(Divider_TC_STOP_SIGNAL_MODE     << Divider_STOP_SHIFT))            |\
         ((uint32)(Divider_TC_START_SIGNAL_MODE    << Divider_START_SHIFT)))
        
#define Divider_TIMER_UPDOWN_CNT_USED                                                          \
                ((Divider__COUNT_UPDOWN0 == Divider_TC_COUNTER_MODE)                  ||\
                 (Divider__COUNT_UPDOWN1 == Divider_TC_COUNTER_MODE))

#define Divider_PWM_UPDOWN_CNT_USED                                                            \
                ((Divider__CENTER == Divider_PWM_ALIGN)                               ||\
                 (Divider__ASYMMETRIC == Divider_PWM_ALIGN))               
        
#define Divider_PWM_PR_INIT_VALUE              (1u)
#define Divider_QUAD_PERIOD_INIT_VALUE         (0x8000u)



#endif /* End CY_TCPWM_Divider_H */

/* [] END OF FILE */
