/*******************************************************************************
* File Name: Divider_PM.c
* Version 2.10
*
* Description:
*  This file contains the setup, control, and status commands to support
*  the component operations in the low power mode.
*
* Note:
*  None
*
********************************************************************************
* Copyright 2013-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "Divider.h"

static Divider_BACKUP_STRUCT Divider_backup;


/*******************************************************************************
* Function Name: Divider_SaveConfig
********************************************************************************
*
* Summary:
*  All configuration registers are retention. Nothing to save here.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void Divider_SaveConfig(void)
{

}


/*******************************************************************************
* Function Name: Divider_Sleep
********************************************************************************
*
* Summary:
*  Stops the component operation and saves the user configuration.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void Divider_Sleep(void)
{
    if(0u != (Divider_BLOCK_CONTROL_REG & Divider_MASK))
    {
        Divider_backup.enableState = 1u;
    }
    else
    {
        Divider_backup.enableState = 0u;
    }

    Divider_Stop();
    Divider_SaveConfig();
}


/*******************************************************************************
* Function Name: Divider_RestoreConfig
********************************************************************************
*
* Summary:
*  All configuration registers are retention. Nothing to restore here.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void Divider_RestoreConfig(void)
{

}


/*******************************************************************************
* Function Name: Divider_Wakeup
********************************************************************************
*
* Summary:
*  Restores the user configuration and restores the enable state.
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void Divider_Wakeup(void)
{
    Divider_RestoreConfig();

    if(0u != Divider_backup.enableState)
    {
        Divider_Enable();
    }
}


/* [] END OF FILE */
